@@ -1,11 +1,12 @@
 from ..core.q import Q
 from ..core import Field
-from ..core.api.special_values import Autogenerate
+from ..core.api.special_values import Autogenerate, OMIT
 from ..core.bindings import RelatedObjectBinding
 from .dataset import Dataset, DatasetTypeBinder
 from .treeq import TreeQBinder
 
 
+
 class FilesystemBinder(DatasetTypeBinder):
     def __init__(self, object_type, system):
         super(FilesystemBinder, self).__init__(object_type, system)
@@ -32,8 +33,17 @@ class Filesystem(Dataset):
               is_sortable=True, default=Autogenerate("fs_{uuid}")),
         Field("root_mode", creation_parameter=True, hidden=True, optional=True),
         Field("atime_mode", is_filterable=True, is_sortable=True),
+        Field("atime_granularity", type=int, mutable=True, creation_parameter=True, optional=True,
+              is_filterable=True, is_sortable=True, new_to="6.0.10"),
         Field("established", api_name="_is_established", type=bool, is_filterable=True, is_sortable=True, new_to="4.0"),
         Field('data_snapshot_guid', is_filterable=True, is_sortable=True, feature_name="nas_replication"),
+        Field("snapdir_name", creation_parameter=True, optional=True, is_filterable=True, is_sortable=True,
+              feature_name="dot_snapshot"),
+        Field("visible_in_snapdir", type=bool, is_filterable=True, is_sortable=True, feature_name="dot_snapshot"),
+        Field("snapdir_accessible", type=bool, feature_name="dot_snapshot", creation_parameter=True, optional=True,
+              is_filterable=True, is_sortable=True),
+        Field("security_style", creation_parameter=True, optional=True,
+              is_filterable=True, is_sortable=True, feature_name="native_smb")
     ]
 
     BINDER_CLASS = FilesystemBinder
@@ -42,8 +52,8 @@ class Filesystem(Dataset):
         super(Filesystem, self).__init__(system, initial_data)
         self.treeqs = self.system.filesystems.get_or_create_treeq_binder(self)
 
-    def delete(self):
-        super(Filesystem, self).delete()
+    def delete(self, force_if_snapshot_locked=OMIT):
+        super(Filesystem, self).delete(force_if_snapshot_locked=force_if_snapshot_locked)
         self.system.filesystems.delete_treeq_binder(self)
 
     @classmethod
@@ -55,3 +65,9 @@ class Filesystem(Dataset):
 
     def get_exports(self):
         return self.system.exports.find(Q.filesystem_id == self.id)
+
+    def add_share(self, **kwargs):
+        return self.system.shares.create(filesystem=self, **kwargs)
+
+    def get_shares(self):
+        return self.system.shares.find(Q.filesystem_id == self.id)
