@@ -72,6 +72,10 @@ class Volume(Dataset):
               binding=RelatedObjectBinding('volumes'), is_filterable=True),
         Field('data_snapshot_guid', is_filterable=True, is_sortable=True, feature_name="nas_replication"),
         Field('paths_available', type=bool, new_to="5.0"),
+        Field("nguid", feature_name="nvme"),
+        Field("snapshot_expires_at", type=int, feature_name="replicate_snapshots"),
+        Field("snapshot_retention", type=int, is_filterable=True, is_sortable=True,
+            feature_name="replicate_snapshots")
     ]
 
     @classmethod
